#!/usr/bin/env python
 
from setuptools import setup

setup(name='cleartest',
    version='0.906',
    description='Lightweight testing framework for Python 2.7',
    long_description="See the project's GitHub page for docs: https://github.com/sbarba/cleartest",
    py_modules=['cleartest'],
    author='The cleartest team',
    license='MIT',
    scripts=['runtests'],
    url='https://github.com/sbarba/cleartest'
)
